# Part

Features in Abaqus/CAE include Parts, Datums, Partitions, and Assembly operations. Part commands create Feature objects on only the Part object. The commands that create Feature objects on only the rootAssembly object are described in Assembly commands. The commands that create Feature objects on both the Part and the rootAssembly objects are described in Feature commands.

## Create parts

```{eval-rst}
.. autoclass:: abaqus.Part.PartModel.PartModel
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

```{eval-rst}
.. autoclass:: abaqus.Part.PartBase.PartBase
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Part
        :recursive:
        :exclude: PartModel, PartBase

    .. placeholder for empty members
```
